@@ -8,16 +8,20 @@ use IO::Socket::UNIX;
 use POSIX qw(locale_h);
 
 our $DATE = '2014-07-06'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                        create_unix_socket
+                       create_unix_stream_socket
+                       create_unix_datagram_socket
                );
 
 sub create_unix_socket {
-    my ($path, $mode) = @_;
+    my ($path, $mode, $opts) = @_;
+
+    $opts //= {};
 
     my $old_locale = setlocale(LC_ALL);
 
@@ -29,6 +33,7 @@ sub create_unix_socket {
         $sock = IO::Socket::UNIX->new(
             Type => SOCK_STREAM,
             Peer => $path,
+            %$opts,
         );
         my $err = $@ unless $sock;
         if ($sock) {
@@ -50,6 +55,7 @@ sub create_unix_socket {
         Type   => SOCK_STREAM,
         Local  => $path,
         Listen => 1,
+        %$opts,
     );
     die "Can't create listening Unix socket: $@" unless $sock;
 
@@ -60,6 +66,18 @@ sub create_unix_socket {
     $sock;
 }
 
+sub create_unix_stream_socket {
+    my ($path, $mode, $opts) = @_;
+    $opts //= {};
+    create_unix_socket($path, $mode, {Type=>SOCK_STREAM, %$opts});
+}
+
+sub create_unix_datagram_socket {
+    my ($path, $mode, $opts) = @_;
+    $opts //= {};
+    create_unix_socket($path, $mode, {Type=>SOCK_DGRAM, %$opts});
+}
+
 1;
 # ABSTRACT: Unix domain socket utilities
 
@@ -75,17 +93,34 @@ SHARYANTO::IO::Socket::UNIX::Util - Unix domain socket utilities
 
 =head1 VERSION
 
-This document describes version 0.02 of SHARYANTO::IO::Socket::UNIX::Util (from Perl distribution SHARYANTO-IO-Socket-Utils), released on 2014-07-06.
+This document describes version 0.03 of SHARYANTO::IO::Socket::UNIX::Util (from Perl distribution SHARYANTO-IO-Socket-Utils), released on 2014-07-06.
 
 =head1 FUNCTIONS
 
-=head2 create_unix_socket($path[, $mode]) => SOCKET
+=head2 create_unix_socket($path[, $mode, \%opts]) => SOCKET
 
-Create a listening Unix socket. Die on failure.
+Create a listening Unix socket (by default with Type SOCK_STREAM) using
+L<IO::SOcket::UNIX>. C<%opts> will be passed to L<IO::Socket::UNIX>.
 
-This function creates Unix domain socket with L<IO::Socket::UNIX> with some
-extra stuffs: remove stale socket first, show more detailed/precise error
-message, chmod with $mode.
+Die on failure.
+
+This function creates Unix domain socket with the usual way of using
+L<IO::Socket::UNIX> with some extra stuffs: remove stale socket first, show more
+detailed/precise error message, chmod with $mode.
+
+=head2 create_unix_stream_socket($path[, $mode, \%opts]) => SOCKET
+
+Shortcut for:
+
+ create_unix_socket($path, $mode, {Type=>SOCK_STREAM, %opts});
+
+which is the default anyway.
+
+=head2 create_unix_datagram_socket($path[, $mode, \%opts]) => SOCKET
+
+Shortcut for:
+
+ create_unix_socket($path, $mode, {Type=>SOCK_DGRAM, %opts});
 
 =head1 SEE ALSO
 
